;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "better-defaults" "20251012.2227"
  "Fixing weird quirks and poor defaults."
  '((emacs "25.1"))
  :url "https://git.sr.ht/~technomancy/better-defaults"
  :commit "b4e566ddd368609c7df711c4f0d9cc345455aa0f"
  :revdesc "b4e566ddd368"
  :keywords '("convenience"))
